"""
Least square solver used by Borea
"""
import numpy as np


def npsolve(mat_a: np.ndarray, mat_b: np.ndarray) -> np.ndarray:
    """
    Solver used by Borea to resolve Ax = B

    Args:
        mat_a (np.ndarray): Matrix A
        mat_b (np.ndarray): Matrix B

    Returns:
        np.ndarray: the result x
    """
    return np.linalg.lstsq(mat_a, mat_b, rcond=None)[0]



"""
Script to check path of data.
"""
from pathlib import Path, PureWindowsPath, PurePosixPath


def check_path(file: str) -> Path:
    """
    Check path of data if Posix of Windows path.

    Args:
        file (str): The path of data.

    Returns:
        Path: The good path.
    """
    file = Path(file)
    name = file.stem

    if "/" in name:
        return Path(PurePosixPath(file))

    if "\\" in name:
        return Path(PureWindowsPath(file))

    return file
